@@ -1,5 +1,5 @@
-{-# LANGUAGE CPP                       #-}
-{-# LANGUAGE DerivingVia               #-}
+{-# LANGUAGE CPP #-}
+{-# LANGUAGE DerivingVia #-}
 {-# OPTIONS_GHC -fno-warn-deprecations #-}
 
 -- |
@@ -17,79 +17,85 @@
 -- @since 0.4.0.0
 module Data.Functor.Invariant.Inplicative (
   -- * Typeclass
-    Inply(..)
-  , Inplicative(..)
-  -- * Deriving
-  , WrappedApplicativeOnly(..)
-  , WrappedDivisibleOnly(..)
-  -- * Invariant 'Day'
-  , runDay
-  , dather
-  , runDayApply
-  , runDayDivise
-  -- * Assembling Helpers
-  , gatheredN
-  , gatheredNMap
-  , gatheredN1
-  , gatheredN1Map
-  , gatheredNRec
-  , gatheredNMapRec
-  , gatheredN1Rec
-  , gatheredN1MapRec
-  , gatherN
-  , gatherN1
-  ) where
+  Inply (..),
+  Inplicative (..),
 
-import           Control.Applicative
-import           Control.Applicative.Backwards               (Backwards(..))
-import           Control.Applicative.Lift                    (Lift(Pure, Other))
-import           Control.Arrow                               (Arrow)
-import           Control.Monad.Trans.Cont                    (ContT)
-import           Control.Monad.Trans.Error                   (ErrorT(..))
-import           Control.Monad.Trans.Except                  (ExceptT(..))
-import           Control.Monad.Trans.Identity                (IdentityT(..))
-import           Control.Monad.Trans.List                    (ListT(..))
-import           Control.Monad.Trans.Maybe                   (MaybeT(..))
-import           Control.Monad.Trans.RWS                     (RWST(..))
-import           Control.Monad.Trans.Reader                  (ReaderT(..))
-import           Control.Monad.Trans.State                   (StateT)
-import           Control.Monad.Trans.Writer                  (WriterT(..))
-import           Control.Natural
-import           Data.Complex                                (Complex)
-import           Data.Deriving
-import           Data.Functor.Apply
-import           Data.Functor.Bind.Class                     (Bind)
-import           Data.Functor.Constant                       (Constant)
-import           Data.Functor.Contravariant
-import           Data.Functor.Contravariant.Divise
-import           Data.Functor.Contravariant.Divisible
-import           Data.Functor.Identity
-import           Data.Functor.Invariant
-import           Data.Functor.Invariant.Day
-import           Data.Functor.Product                        (Product(..))
-import           Data.Functor.Reverse                        (Reverse(..))
-import           Data.Hashable                               (Hashable)
-import           Data.Kind
-import           Data.List.NonEmpty                          (NonEmpty)
-import           Data.SOP hiding                             (hmap)
-import           Data.Sequence                               (Seq)
-import           Data.StateVar                               (SettableStateVar)
-import           Data.Tagged                                 (Tagged)
-import           Data.Tree                                   (Tree)
-import           GHC.Generics                                (Generic)
-import qualified Control.Monad.Trans.RWS.Strict as Strict    (RWST(..))
-import qualified Control.Monad.Trans.State.Strict as Strict  (StateT)
-import qualified Control.Monad.Trans.Writer.Strict as Strict (WriterT(..))
-import qualified Data.HashMap.Lazy                           as HM
-import qualified Data.IntMap                                 as IM
-import qualified Data.Map                                    as M
-import qualified Data.Monoid                                 as Monoid
-import qualified Data.Semigroup                              as Semigroup
-import qualified Data.Sequence.NonEmpty                      as NESeq
-import qualified Data.Vinyl                                  as V
-import qualified Data.Vinyl.Curry                            as V
-import qualified Data.Vinyl.Functor                          as V
-import qualified GHC.Generics                                as Generics
+  -- * Deriving
+  WrappedApplicativeOnly (..),
+  WrappedDivisibleOnly (..),
+
+  -- * Invariant 'Day'
+  runDay,
+  dather,
+  runDayApply,
+  runDayDivise,
+
+  -- * Assembling Helpers
+  gatheredN,
+  gatheredNMap,
+  gatheredN1,
+  gatheredN1Map,
+  gatheredNRec,
+  gatheredNMapRec,
+  gatheredN1Rec,
+  gatheredN1MapRec,
+  gatherN,
+  gatherN1,
+) where
+
+import Control.Applicative
+import Control.Applicative.Backwards (Backwards (..))
+import Control.Applicative.Lift (Lift (Other, Pure))
+import Control.Arrow (Arrow)
+import Control.Monad.Trans.Cont (ContT)
+import Control.Monad.Trans.Except (ExceptT (..))
+import Control.Monad.Trans.Identity (IdentityT (..))
+import Control.Monad.Trans.Maybe (MaybeT (..))
+import Control.Monad.Trans.RWS (RWST (..))
+import qualified Control.Monad.Trans.RWS.Strict as Strict (RWST (..))
+import Control.Monad.Trans.Reader (ReaderT (..))
+import Control.Monad.Trans.State (StateT)
+import qualified Control.Monad.Trans.State.Strict as Strict (StateT)
+import Control.Monad.Trans.Writer (WriterT (..))
+import qualified Control.Monad.Trans.Writer.Strict as Strict (WriterT (..))
+import Control.Natural
+import Data.Complex (Complex)
+import Data.Deriving
+import Data.Functor.Apply
+import Data.Functor.Bind.Class (Bind)
+import Data.Functor.Constant (Constant)
+import Data.Functor.Contravariant
+import Data.Functor.Contravariant.Divise
+import Data.Functor.Contravariant.Divisible
+import Data.Functor.Identity
+import Data.Functor.Invariant
+import Data.Functor.Invariant.Day
+import Data.Functor.Product (Product (..))
+import Data.Functor.Reverse (Reverse (..))
+import qualified Data.HashMap.Lazy as HM
+import Data.Hashable (Hashable)
+import qualified Data.IntMap as IM
+import Data.Kind
+import Data.List.NonEmpty (NonEmpty)
+import qualified Data.Map as M
+import qualified Data.Monoid as Monoid
+import Data.SOP hiding (hmap)
+import qualified Data.Semigroup as Semigroup
+import Data.Sequence (Seq)
+import qualified Data.Sequence.NonEmpty as NESeq
+import Data.StateVar (SettableStateVar)
+import Data.Tagged (Tagged)
+import Data.Tree (Tree)
+import qualified Data.Vinyl as V
+import qualified Data.Vinyl.Curry as V
+import qualified Data.Vinyl.Functor as V
+import GHC.Generics (Generic)
+import qualified GHC.Generics as Generics
+
+#if !MIN_VERSION_transformers(0,6,0)
+import           Control.Monad.Trans.Error
+import           Control.Monad.Trans.List
+#endif
 
 -- | The invariant counterpart of 'Apply' and 'Divise'.
 --
@@ -109,41 +115,43 @@ import qualified GHC.Generics                                as Generics
 --
 -- @since 0.4.0.0
 class Invariant f => Inply f where
-    -- | Like '<.>', '<*>', 'divise', or 'divide', but requires both
-    -- a splitting and a recombining function.  '<.>' and '<*>' require
-    -- only a combining function, and 'divise' and 'divide' require only
-    -- a splitting function.
-    --
-    -- It is used to merge @f b@ (producer and consumer of @b@) and @f c@
-    -- (producer and consumer of @c@) into a @f a@.  You can think of it
-    -- as, for the @f a@, it "splits" the a into @b@ and @c@ with the @a ->
-    -- (b, c)@, feeds it to the original @f b@ and @f c@, and then
-    -- re-combines the output back into a @a@ with the @b -> c -> a@.
-    --
-    -- An important property is that it will always use @both@ of the
-    -- ccomponents given in order to fulfil its job.  If you gather an @f
-    -- a@ and an @f b@ into an @f c@, in order to consume/produdce the @c@,
-    -- it will always use both the @f a@ or the @f b@ -- exactly one of
-    -- them.
-    --
-    -- @since 0.4.0.0
-    gather
-        :: (b -> c -> a)
-        -> (a -> (b, c))
-        -> f b
-        -> f c
-        -> f a
-    gather f g x y = invmap (uncurry f) g (gathered x y)
-    -- | A simplified version of 'gather' that combines into a tuple.  You
-    -- can then use 'invmap' to reshape it into the proper shape.
-    --
-    -- @since 0.4.0.0
-    gathered
-        :: f a
-        -> f b
-        -> f (a, b)
-    gathered = gather (,) id
-    {-# MINIMAL gather | gathered #-}
+  -- | Like '<.>', '<*>', 'divise', or 'divide', but requires both
+  -- a splitting and a recombining function.  '<.>' and '<*>' require
+  -- only a combining function, and 'divise' and 'divide' require only
+  -- a splitting function.
+  --
+  -- It is used to merge @f b@ (producer and consumer of @b@) and @f c@
+  -- (producer and consumer of @c@) into a @f a@.  You can think of it
+  -- as, for the @f a@, it "splits" the a into @b@ and @c@ with the @a ->
+  -- (b, c)@, feeds it to the original @f b@ and @f c@, and then
+  -- re-combines the output back into a @a@ with the @b -> c -> a@.
+  --
+  -- An important property is that it will always use @both@ of the
+  -- ccomponents given in order to fulfil its job.  If you gather an @f
+  -- a@ and an @f b@ into an @f c@, in order to consume/produdce the @c@,
+  -- it will always use both the @f a@ or the @f b@ -- exactly one of
+  -- them.
+  --
+  -- @since 0.4.0.0
+  gather ::
+    (b -> c -> a) ->
+    (a -> (b, c)) ->
+    f b ->
+    f c ->
+    f a
+  gather f g x y = invmap (uncurry f) g (gathered x y)
+
+  -- | A simplified version of 'gather' that combines into a tuple.  You
+  -- can then use 'invmap' to reshape it into the proper shape.
+  --
+  -- @since 0.4.0.0
+  gathered ::
+    f a ->
+    f b ->
+    f (a, b)
+  gathered = gather (,) id
+
+  {-# MINIMAL gather | gathered #-}
 
 -- | The invariant counterpart of 'Applicative' and 'Divisible'.
 --
@@ -157,7 +165,7 @@ class Invariant f => Inply f where
 --
 -- @since 0.4.0.0
 class Inply f => Inplicative f where
-    knot :: a -> f a
+  knot :: a -> f a
 
 -- | Interpret out of a contravariant 'Day' into any instance of 'Inply' by
 -- providing two interpreting functions.
@@ -166,11 +174,11 @@ class Inply f => Inplicative f where
 -- a different package.
 --
 -- @since 0.4.0.0
-runDay
-    :: Inply h
-    => (f ~> h)
-    -> (g ~> h)
-    -> Day f g ~> h
+runDay ::
+  Inply h =>
+  (f ~> h) ->
+  (g ~> h) ->
+  Day f g ~> h
 runDay f g (Day x y a b) = gather a b (f x) (g y)
 
 -- | Squash the two items in a 'Day' using their natural 'Inply'
@@ -180,38 +188,40 @@ runDay f g (Day x y a b) = gather a b (f x) (g y)
 -- a different package.
 --
 -- @since 0.4.0.0
-dather
-    :: Inply f
-    => Day f f ~> f
+dather ::
+  Inply f =>
+  Day f f ~> f
 dather (Day x y a b) = gather a b x y
 
 -- | Ignores the contravariant part of 'gather'
 instance Apply f => Inply (WrappedFunctor f) where
-    gather f _ (WrapFunctor x) (WrapFunctor y) = WrapFunctor (liftF2 f x y)
-    gathered (WrapFunctor x) (WrapFunctor y) = WrapFunctor (liftF2 (,) x y)
+  gather f _ (WrapFunctor x) (WrapFunctor y) = WrapFunctor (liftF2 f x y)
+  gathered (WrapFunctor x) (WrapFunctor y) = WrapFunctor (liftF2 (,) x y)
+
 -- | @'knot' = 'pure'@
 instance (Applicative f, Apply f) => Inplicative (WrappedFunctor f) where
-    knot = pure
+  knot = pure
 
 -- | Ignores the covariant part of 'gather'
 instance Divise f => Inply (WrappedContravariant f) where
-    gather _ g (WrapContravariant x) (WrapContravariant y) = WrapContravariant (divise g x y)
-    gathered (WrapContravariant x) (WrapContravariant y) = WrapContravariant (divised x y)
+  gather _ g (WrapContravariant x) (WrapContravariant y) = WrapContravariant (divise g x y)
+  gathered (WrapContravariant x) (WrapContravariant y) = WrapContravariant (divised x y)
+
 -- | @'knot' _ = 'conquer'@
 instance (Divisible f, Divise f) => Inplicative (WrappedContravariant f) where
-    knot _ = conquer
+  knot _ = conquer
 
 -- | Ignores the covariant part of 'gather'
 instance Divise f => Inply (WrappedDivisible f) where
-    gather _ g (WrapDivisible x) (WrapDivisible y) = WrapDivisible (divise g x y)
-    gathered (WrapDivisible x) (WrapDivisible y) = WrapDivisible (divised x y)
+  gather _ g (WrapDivisible x) (WrapDivisible y) = WrapDivisible (divise g x y)
+  gathered (WrapDivisible x) (WrapDivisible y) = WrapDivisible (divised x y)
+
 -- | @'knot' _ = 'conquer'@
 instance (Divisible f, Divise f) => Inplicative (WrappedDivisible f) where
-    knot _ = conquer
+  knot _ = conquer
 
 -- | Wrap an 'Applicative' that is not necessarily an 'Apply'.
-newtype WrappedApplicativeOnly f a =
-    WrapApplicativeOnly { unwrapApplicativeOnly :: f a }
+newtype WrappedApplicativeOnly f a = WrapApplicativeOnly {unwrapApplicativeOnly :: f a}
   deriving (Generic, Eq, Show, Ord, Read, Functor, Foldable, Traversable)
   deriving newtype (Applicative, Monad)
 
@@ -221,20 +231,21 @@ deriveEq1 ''WrappedApplicativeOnly
 deriveOrd1 ''WrappedApplicativeOnly
 
 instance Invariant f => Invariant (WrappedApplicativeOnly f) where
-    invmap f g (WrapApplicativeOnly x) = WrapApplicativeOnly (invmap f g x)
+  invmap f g (WrapApplicativeOnly x) = WrapApplicativeOnly (invmap f g x)
 instance (Applicative f, Invariant f) => Apply (WrappedApplicativeOnly f) where
-    x <.> y = x <*> y
+  x <.> y = x <*> y
+
 -- | Ignores the contravariant part of 'gather'
 instance (Applicative f, Invariant f) => Inply (WrappedApplicativeOnly f) where
-    gather f _ (WrapApplicativeOnly x) (WrapApplicativeOnly y) = WrapApplicativeOnly (liftA2 f x y)
-    gathered (WrapApplicativeOnly x) (WrapApplicativeOnly y) = WrapApplicativeOnly (liftA2 (,) x y)
+  gather f _ (WrapApplicativeOnly x) (WrapApplicativeOnly y) = WrapApplicativeOnly (liftA2 f x y)
+  gathered (WrapApplicativeOnly x) (WrapApplicativeOnly y) = WrapApplicativeOnly (liftA2 (,) x y)
+
 -- | @'knot' = 'pure'@
 instance (Applicative f, Invariant f) => Inplicative (WrappedApplicativeOnly f) where
-    knot = pure
+  knot = pure
 
 -- | Wrap an 'Divisible' that is not necessarily a 'Divise'.
-newtype WrappedDivisibleOnly f a =
-    WrapDivisibleOnly { unwrapDivisibleOnly :: f a }
+newtype WrappedDivisibleOnly f a = WrapDivisibleOnly {unwrapDivisibleOnly :: f a}
   deriving (Generic, Eq, Show, Ord, Read, Functor, Foldable, Traversable)
   deriving newtype (Divisible, Contravariant)
 
@@ -244,64 +255,80 @@ deriveEq1 ''WrappedDivisibleOnly
 deriveOrd1 ''WrappedDivisibleOnly
 
 instance Invariant f => Invariant (WrappedDivisibleOnly f) where
-    invmap f g (WrapDivisibleOnly x) = WrapDivisibleOnly (invmap f g x)
+  invmap f g (WrapDivisibleOnly x) = WrapDivisibleOnly (invmap f g x)
 instance (Divisible f, Invariant f) => Divise (WrappedDivisibleOnly f) where
-    divise g (WrapDivisibleOnly x) (WrapDivisibleOnly y) = WrapDivisibleOnly (divide g x y)
+  divise g (WrapDivisibleOnly x) (WrapDivisibleOnly y) = WrapDivisibleOnly (divide g x y)
+
 -- | Ignores the covariant part of 'gather'
 instance (Divisible f, Invariant f) => Inply (WrappedDivisibleOnly f) where
-    gather _ g (WrapDivisibleOnly x) (WrapDivisibleOnly y) = WrapDivisibleOnly (divide g x y)
-    gathered (WrapDivisibleOnly x) (WrapDivisibleOnly y) = WrapDivisibleOnly (divided x y)
+  gather _ g (WrapDivisibleOnly x) (WrapDivisibleOnly y) = WrapDivisibleOnly (divide g x y)
+  gathered (WrapDivisibleOnly x) (WrapDivisibleOnly y) = WrapDivisibleOnly (divided x y)
+
 -- | @'knot' _ = 'conquer'@
 instance (Divisible f, Invariant f) => Inplicative (WrappedDivisibleOnly f) where
-    knot _ = conquer
+  knot _ = conquer
 
 funzip :: Functor f => f (a, b) -> (f a, f b)
 funzip x = (fmap fst x, fmap snd x)
 
 -- | @since 0.4.1.0
 instance Inply f => Inply (MaybeT f) where
-    gather f g (MaybeT x) (MaybeT y) = MaybeT $
+  gather f g (MaybeT x) (MaybeT y) =
+    MaybeT $
       gather (liftA2 f) (funzip . fmap g) x y
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (MaybeT f) where
-    knot x = MaybeT (knot (Just x))
+  knot x = MaybeT (knot (Just x))
 
 -- | @since 0.4.1.0
 instance (Inply f, Semigroup w) => Inply (WriterT w f) where
-    gather f g (WriterT x) (WriterT y) = WriterT $
-      gather (\case (a, q) -> \case (b, r) -> (f a b, q <> r))
-             (\case (a, s) -> case g a of (b, c) -> ((b, s), (c, s)))
-             x y
+  gather f g (WriterT x) (WriterT y) =
+    WriterT $
+      gather
+        (\case (a, q) -> \case (b, r) -> (f a b, q <> r))
+        (\case (a, s) -> case g a of (b, c) -> ((b, s), (c, s)))
+        x
+        y
+
 -- | @since 0.4.1.0
 instance (Inplicative f, Monoid w) => Inplicative (WriterT w f) where
-    knot x = WriterT (knot (x, mempty))
+  knot x = WriterT (knot (x, mempty))
 
 -- | @since 0.4.1.0
 instance (Inply f, Semigroup w) => Inply (Strict.WriterT w f) where
-    gather f g (Strict.WriterT x) (Strict.WriterT y) = Strict.WriterT $
-      gather (\(~(a, q)) (~(b, r)) -> (f a b, q <> r))
-             (\(~(a, s)) -> let ~(b, c) = g a in ((b, s), (c, s)))
-             x y
+  gather f g (Strict.WriterT x) (Strict.WriterT y) =
+    Strict.WriterT $
+      gather
+        (\(~(a, q)) (~(b, r)) -> (f a b, q <> r))
+        (\(~(a, s)) -> let ~(b, c) = g a in ((b, s), (c, s)))
+        x
+        y
+
 -- | @since 0.4.1.0
 instance (Inplicative f, Monoid w) => Inplicative (Strict.WriterT w f) where
-    knot x = Strict.WriterT (knot (x, mempty))
+  knot x = Strict.WriterT (knot (x, mempty))
 
 -- | @since 0.4.1.0
 instance Inply f => Inply (ReaderT r f) where
-    gather f g (ReaderT x) (ReaderT y) = ReaderT $ \r ->
-      gather f g (x r) (y r)
+  gather f g (ReaderT x) (ReaderT y) = ReaderT $ \r ->
+    gather f g (x r) (y r)
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (ReaderT r f) where
-    knot x = ReaderT (\_ -> knot x)
+  knot x = ReaderT (\_ -> knot x)
 
 -- | @since 0.4.1.0
 instance Inply f => Inply (ExceptT e f) where
-    gather f g (ExceptT x) (ExceptT y) = ExceptT $
+  gather f g (ExceptT x) (ExceptT y) =
+    ExceptT $
       gather (liftA2 f) (funzip . fmap g) x y
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (ExceptT e f) where
-    knot x = ExceptT (knot (Right x))
+  knot x = ExceptT (knot (Right x))
 
+#if !MIN_VERSION_transformers(0,6,0)
 -- | @since 0.4.1.0
 instance Inply f => Inply (ErrorT e f) where
     gather f g (ErrorT x) (ErrorT y) = ErrorT $
@@ -317,150 +344,232 @@ instance Inply f => Inply (ListT f) where
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (ListT f) where
     knot x = ListT (knot [x])
+#endif
 
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (RWST r w s m) instance (Bind m, Invariant m, Semigroup w) => Inply (RWST r w s m)
+deriving via
+  WrappedFunctor (RWST r w s m)
+  instance
+    (Bind m, Invariant m, Semigroup w) => Inply (RWST r w s m)
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (RWST r w s m) instance (Monad m, Bind m, Invariant m, Monoid w) => Inplicative (RWST r w s m)
+deriving via
+  WrappedFunctor (RWST r w s m)
+  instance
+    (Monad m, Bind m, Invariant m, Monoid w) => Inplicative (RWST r w s m)
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (Strict.RWST r w s m) instance (Bind m, Invariant m, Semigroup w) => Inply (Strict.RWST r w s m)
+deriving via
+  WrappedFunctor (Strict.RWST r w s m)
+  instance
+    (Bind m, Invariant m, Semigroup w) => Inply (Strict.RWST r w s m)
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (Strict.RWST r w s m) instance (Monad m, Bind m, Invariant m, Monoid w) => Inplicative (Strict.RWST r w s m)
+deriving via
+  WrappedFunctor (Strict.RWST r w s m)
+  instance
+    (Monad m, Bind m, Invariant m, Monoid w) => Inplicative (Strict.RWST r w s m)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (StateT s m) instance (Bind m, Invariant m) => Inply (StateT s m)
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (StateT s m) instance (Monad m, Bind m, Invariant m) => Inplicative (StateT s m)
+deriving via
+  WrappedFunctor (StateT s m)
+  instance
+    (Monad m, Bind m, Invariant m) => Inplicative (StateT s m)
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (Strict.StateT s m) instance (Bind m, Invariant m) => Inply (Strict.StateT s m)
+deriving via
+  WrappedFunctor (Strict.StateT s m)
+  instance
+    (Bind m, Invariant m) => Inply (Strict.StateT s m)
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (Strict.StateT s m) instance (Monad m, Bind m, Invariant m) => Inplicative (Strict.StateT s m)
+deriving via
+  WrappedFunctor (Strict.StateT s m)
+  instance
+    (Monad m, Bind m, Invariant m) => Inplicative (Strict.StateT s m)
 
 -- | @since 0.4.1.0
 instance Inply f => Inply (Generics.M1 i t f :: Type -> Type) where
-    gather f g (Generics.M1 x) (Generics.M1 y) = Generics.M1 (gather f g x y)
+  gather f g (Generics.M1 x) (Generics.M1 y) = Generics.M1 (gather f g x y)
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (Generics.M1 i t f :: Type -> Type) where
-    knot = Generics.M1 . knot
+  knot = Generics.M1 . knot
+
 -- | @since 0.4.1.0
 instance (Inply f, Inply g) => Inply (f Generics.:*: g) where
-    gather f g (x1 Generics.:*: y1) (x2 Generics.:*: y2) =
-        gather f g x1 x2 Generics.:*: gather f g y1 y2
+  gather f g (x1 Generics.:*: y1) (x2 Generics.:*: y2) =
+    gather f g x1 x2 Generics.:*: gather f g y1 y2
+
 -- | @since 0.4.1.0
 instance (Inplicative f, Inplicative g) => Inplicative (f Generics.:*: g) where
-    knot x = knot x Generics.:*: knot x
+  knot x = knot x Generics.:*: knot x
+
 -- | @since 0.4.1.0
 instance (Inply f, Inply g) => Inply (Product f g) where
-    gather f g (Pair x1 y1) (Pair x2 y2) =
-      gather f g x1 x2 `Pair` gather f g y1 y2
+  gather f g (Pair x1 y1) (Pair x2 y2) =
+    gather f g x1 x2 `Pair` gather f g y1 y2
+
 -- | @since 0.4.1.0
 instance (Inplicative f, Inplicative g) => Inplicative (Product f g) where
-    knot x = knot x `Pair` knot x
+  knot x = knot x `Pair` knot x
+
 -- | @since 0.4.1.0
 instance Inply f => Inply (Generics.Rec1 f :: Type -> Type) where
-    gather f g (Generics.Rec1 x) (Generics.Rec1 y) = Generics.Rec1 (gather f g x y)
+  gather f g (Generics.Rec1 x) (Generics.Rec1 y) = Generics.Rec1 (gather f g x y)
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (Generics.Rec1 f :: Type -> Type) where
-    knot = Generics.Rec1 . knot
+  knot = Generics.Rec1 . knot
+
 -- | @since 0.4.1.0
 instance Inply f => Inply (Monoid.Alt f) where
-    gather f g (Monoid.Alt x) (Monoid.Alt y) = Monoid.Alt (gather f g x y)
+  gather f g (Monoid.Alt x) (Monoid.Alt y) = Monoid.Alt (gather f g x y)
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (Monoid.Alt f) where
-    knot = Monoid.Alt . knot
+  knot = Monoid.Alt . knot
+
 -- | @since 0.4.1.0
 instance Inply f => Inply (IdentityT f :: Type -> Type) where
-    gather f g (IdentityT x) (IdentityT y) = IdentityT (gather f g x y)
+  gather f g (IdentityT x) (IdentityT y) = IdentityT (gather f g x y)
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (IdentityT f :: Type -> Type) where
-    knot = IdentityT . knot
+  knot = IdentityT . knot
+
 -- | @since 0.4.1.0
 instance Inply f => Inply (Reverse f :: Type -> Type) where
-    gather f g (Reverse x) (Reverse y) = Reverse (gather f g x y)
+  gather f g (Reverse x) (Reverse y) = Reverse (gather f g x y)
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (Reverse f :: Type -> Type) where
-    knot = Reverse . knot
+  knot = Reverse . knot
+
 -- | @since 0.4.1.0
 instance Inply f => Inply (Backwards f :: Type -> Type) where
-    gather f g (Backwards x) (Backwards y) = Backwards (gather f g x y)
+  gather f g (Backwards x) (Backwards y) = Backwards (gather f g x y)
+
 -- | @since 0.4.1.0
 instance Inplicative f => Inplicative (Backwards f :: Type -> Type) where
-    knot = Backwards . knot
+  knot = Backwards . knot
+
 -- | @since 0.4.1.0
 instance Inply f => Inply (Lift f) where
-    gather f g = \case
-      Pure  x -> \case
-        Pure  y -> Pure (f x y)
-        Other y -> Other (invmap (f x) (snd . g) y)
-      Other x -> \case
-        Pure  y -> Other (invmap (`f` y) (fst . g) x)
-        Other y -> Other (gather f g x y)
+  gather f g = \case
+    Pure x -> \case
+      Pure y -> Pure (f x y)
+      Other y -> Other (invmap (f x) (snd . g) y)
+    Other x -> \case
+      Pure y -> Other (invmap (`f` y) (fst . g) x)
+      Other y -> Other (gather f g x y)
+
 -- | @since 0.4.1.0
 instance Inply f => Inplicative (Lift f) where
-    knot = Pure
+  knot = Pure
 
 -- | @since 0.4.1.0
 deriving via WrappedApplicativeOnly (Tagged a) instance Inply (Tagged a)
+
 -- | @since 0.4.1.0
 deriving via WrappedApplicativeOnly (Tagged a) instance Inplicative (Tagged a)
 
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Identity instance Inply Identity
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Identity instance Inplicative Identity
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Proxy :: Type -> Type) instance Inply Proxy
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Proxy :: Type -> Type) instance Inplicative Proxy
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor [] instance Inply []
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor [] instance Inplicative []
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor ((->) r) instance Inply ((->) r)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor ((->) r) instance Inplicative ((->) r)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Maybe instance Inply Maybe
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Maybe instance Inplicative Maybe
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Either e) instance Inply (Either e)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Either e) instance Inplicative (Either e)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor IO instance Inply IO
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor IO instance Inplicative IO
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Generics.Par1 instance Inply Generics.Par1
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Generics.Par1 instance Inplicative Generics.Par1
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Generics.U1 :: Type -> Type) instance Inply Generics.U1
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Generics.U1 :: Type -> Type) instance Inplicative Generics.U1
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (Generics.K1 i c :: Type -> Type) instance Semigroup c => Inply (Generics.K1 i c)
+deriving via
+  WrappedFunctor (Generics.K1 i c :: Type -> Type)
+  instance
+    Semigroup c => Inply (Generics.K1 i c)
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (Generics.K1 i c :: Type -> Type) instance Monoid c => Inplicative (Generics.K1 i c)
+deriving via
+  WrappedFunctor (Generics.K1 i c :: Type -> Type)
+  instance
+    Monoid c => Inplicative (Generics.K1 i c)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Complex instance Inply Complex
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Complex instance Inplicative Complex
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Semigroup.Min instance Inply Semigroup.Min
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Semigroup.Min instance Inplicative Semigroup.Min
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Semigroup.Max instance Inply Semigroup.Max
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Semigroup.Max instance Inplicative Semigroup.Max
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Semigroup.First instance Inply Semigroup.First
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Semigroup.First instance Inplicative Semigroup.First
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Semigroup.Last instance Inply Semigroup.Last
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Semigroup.Last instance Inplicative Semigroup.Last
 
@@ -473,50 +582,73 @@ deriving via WrappedFunctor Semigroup.Option instance Inplicative Semigroup.Opti
 
 -- | @since 0.4.1.0
 deriving via WrappedFunctor ZipList instance Inply ZipList
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor ZipList instance Inplicative ZipList
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.First instance Inply Monoid.First
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.First instance Inplicative Monoid.First
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.Last instance Inply Monoid.Last
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.Last instance Inplicative Monoid.Last
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.Dual instance Inply Monoid.Dual
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.Dual instance Inplicative Monoid.Dual
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.Sum instance Inply Monoid.Sum
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.Sum instance Inplicative Monoid.Sum
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.Product instance Inply Monoid.Product
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Monoid.Product instance Inplicative Monoid.Product
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor NonEmpty instance Inply NonEmpty
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor NonEmpty instance Inplicative NonEmpty
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Tree instance Inply Tree
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Tree instance Inplicative Tree
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Seq instance Inply Seq
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor Seq instance Inplicative Seq
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor NESeq.NESeq instance Inply NESeq.NESeq
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (WrappedArrow a b) instance Arrow a => Inply (WrappedArrow a b)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (WrappedArrow a b) instance Arrow a => Inplicative (WrappedArrow a b)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Generics.V1 :: Type -> Type) instance Inply Generics.V1
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor IM.IntMap instance Inply IM.IntMap
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (M.Map k) instance Ord k => Inply (M.Map k)
 
@@ -532,49 +664,67 @@ deriving via WrappedFunctor (HM.HashMap k) instance (Hashable k, Eq k) => Inply
 
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Const w :: Type -> Type) instance Semigroup w => Inply (Const w)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Const w :: Type -> Type) instance Monoid w => Inplicative (Const w)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (Constant w :: Type -> Type) instance Semigroup w => Inply (Constant w)
+
 -- | @since 0.4.1.0
-deriving via WrappedFunctor (Constant w :: Type -> Type) instance Monoid w => Inplicative (Constant w)
+deriving via
+  WrappedFunctor (Constant w :: Type -> Type)
+  instance
+    Monoid w => Inplicative (Constant w)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (ContT r (m :: Type -> Type)) instance Inply (ContT r m)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (ContT r (m :: Type -> Type)) instance Inplicative (ContT r m)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (WrappedMonad m) instance Monad m => Inply (WrappedMonad m)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor (WrappedMonad m) instance Monad m => Inplicative (WrappedMonad m)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor ((,) w :: Type -> Type) instance Semigroup w => Inply ((,) w)
+
 -- | @since 0.4.1.0
 deriving via WrappedFunctor ((,) w :: Type -> Type) instance Monoid w => Inplicative ((,) w)
 
 -- | @since 0.4.1.0
 deriving via WrappedDivisible SettableStateVar instance Inply SettableStateVar
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible SettableStateVar instance Inplicative SettableStateVar
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible Predicate instance Inply Predicate
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible Predicate instance Inplicative Predicate
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible Comparison instance Inply Comparison
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible Comparison instance Inplicative Comparison
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible Equivalence instance Inply Equivalence
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible Equivalence instance Inplicative Equivalence
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible (Op r) instance Semigroup r => Inply (Op r)
+
 -- | @since 0.4.1.0
 deriving via WrappedDivisible (Op r) instance Monoid r => Inplicative (Op r)
 
-
-
-
 -- | Convenient wrapper to build up an 'Inplicative' instance by providing
 -- each component of it.  This makes it much easier to build up longer
 -- chains because you would only need to write the splitting/joining
@@ -609,13 +759,14 @@ deriving via WrappedDivisible (Op r) instance Monoid r => Inplicative (Op r)
 --      otherwise you'd need to manually peel off tuples one-by-one.
 --
 -- @since 0.4.1.0
-gatheredN
-    :: Inplicative f
-    => NP f as
-    -> f (NP I as)
+gatheredN ::
+  Inplicative f =>
+  NP f as ->
+  f (NP I as)
 gatheredN = \case
-    Nil     -> knot Nil
-    x :* xs -> gather
+  Nil -> knot Nil
+  x :* xs ->
+    gather
       (\y ys -> I y :* ys)
       (\case I y :* ys -> (y, ys))
       x
@@ -649,25 +800,26 @@ gatheredN = \case
 -- See notes on 'gatheredNMap' for more details and caveats.
 --
 -- @since 0.4.1.0
-gatheredNMap
-    :: Inplicative f
-    => (NP I as -> b)
-    -> (b -> NP I as)
-    -> NP f as
-    -> f b
+gatheredNMap ::
+  Inplicative f =>
+  (NP I as -> b) ->
+  (b -> NP I as) ->
+  NP f as ->
+  f b
 gatheredNMap f g = invmap f g . gatheredN
 
 -- | A version of 'gatheredN' for non-empty 'NP', but only
 -- requiring an 'Inply' instance.
 --
 -- @since 0.4.1.0
-gatheredN1
-    :: Inply f
-    => NP f (a ': as)
-    -> f (NP I (a ': as))
+gatheredN1 ::
+  Inply f =>
+  NP f (a ': as) ->
+  f (NP I (a ': as))
 gatheredN1 (x :* xs) = case xs of
-    Nil    -> invmap ((:* Nil) . I) (\case I y :* _ -> y) x
-    _ :* _ -> gather
+  Nil -> invmap ((:* Nil) . I) (\case I y :* _ -> y) x
+  _ :* _ ->
+    gather
       (\y ys -> I y :* ys)
       (\case I y :* ys -> (y, ys))
       x
@@ -677,12 +829,12 @@ gatheredN1 (x :* xs) = case xs of
 -- requiring an 'Inply' instance.
 --
 -- @since 0.4.1.0
-gatheredN1Map
-    :: Inplicative f
-    => (NP I (a ': as) -> b)
-    -> (b -> NP I (a ': as))
-    -> NP f (a ': as)
-    -> f b
+gatheredN1Map ::
+  Inplicative f =>
+  (NP I (a ': as) -> b) ->
+  (b -> NP I (a ': as)) ->
+  NP f (a ': as) ->
+  f b
 gatheredN1Map f g = invmap f g . gatheredN1
 
 -- | A version of 'gatheredN' using 'V.XRec' from /vinyl/ instead of
@@ -690,13 +842,14 @@ gatheredN1Map f g = invmap f g . gatheredN1
 -- require manual unwrapping/wrapping of tuple components.
 --
 -- @since 0.4.1.0
-gatheredNRec
-    :: Inplicative f
-    => V.Rec f as
-    -> f (V.XRec V.Identity as)
+gatheredNRec ::
+  Inplicative f =>
+  V.Rec f as ->
+  f (V.XRec V.Identity as)
 gatheredNRec = \case
-    V.RNil    -> knot V.RNil
-    x V.:& xs -> gather
+  V.RNil -> knot V.RNil
+  x V.:& xs ->
+    gather
       (V.::&)
       (\case y V.::& ys -> (y, ys))
       x
@@ -707,12 +860,12 @@ gatheredNRec = \case
 -- require manual unwrapping/wrapping of tuple components.
 --
 -- @since 0.4.1.0
-gatheredNMapRec
-    :: Inplicative f
-    => (V.XRec V.Identity as -> b)
-    -> (b -> V.XRec V.Identity as)
-    -> V.Rec f as
-    -> f b
+gatheredNMapRec ::
+  Inplicative f =>
+  (V.XRec V.Identity as -> b) ->
+  (b -> V.XRec V.Identity as) ->
+  V.Rec f as ->
+  f b
 gatheredNMapRec f g = invmap f g . gatheredNRec
 
 -- | Convenient wrapper to 'gather' over multiple arguments using tine
@@ -758,27 +911,30 @@ gatheredNMapRec f g = invmap f g . gatheredNRec
 -- @
 --
 -- @since 0.4.1.0
-gatherN
-    :: forall f as b. (Inplicative f, V.IsoXRec V.Identity as, V.RecordCurry as)
-    => V.Curried as b
-    -> (b -> V.XRec V.Identity as)
-    -> V.CurriedF f as (f b)
-gatherN f g = V.rcurry @as @f $
+gatherN ::
+  forall f as b.
+  (Inplicative f, V.IsoXRec V.Identity as, V.RecordCurry as) =>
+  V.Curried as b ->
+  (b -> V.XRec V.Identity as) ->
+  V.CurriedF f as (f b)
+gatherN f g =
+  V.rcurry @as @f $
     invmap (V.runcurry' f . V.fromXRec) g
-  . gatheredNRec
+      . gatheredNRec
 
 -- | A version of 'gatheredN1' using 'V.XRec' from /vinyl/ instead of
 -- 'NP' from /sop-core/.  This can be more convenient because it doesn't
 -- require manual unwrapping/wrapping of components.
 --
 -- @since 0.4.1.0
-gatheredN1Rec
-    :: Inply f
-    => V.Rec f (a ': as)
-    -> f (V.XRec V.Identity (a ': as))
+gatheredN1Rec ::
+  Inply f =>
+  V.Rec f (a ': as) ->
+  f (V.XRec V.Identity (a ': as))
 gatheredN1Rec (x V.:& xs) = case xs of
-    V.RNil   -> invmap (V.::& V.RNil) (\case z V.::& _ -> z) x
-    _ V.:& _ -> gather
+  V.RNil -> invmap (V.::& V.RNil) (\case z V.::& _ -> z) x
+  _ V.:& _ ->
+    gather
       (V.::&)
       (\case y V.::& ys -> (y, ys))
       x
@@ -789,26 +945,28 @@ gatheredN1Rec (x V.:& xs) = case xs of
 -- require manual unwrapping/wrapping of tuple components.
 --
 -- @since 0.4.1.0
-gatheredN1MapRec
-    :: Inplicative f
-    => (V.XRec V.Identity (a ': as) -> b)
-    -> (b -> V.XRec V.Identity (a ': as))
-    -> V.Rec f (a ': as)
-    -> f b
+gatheredN1MapRec ::
+  Inplicative f =>
+  (V.XRec V.Identity (a ': as) -> b) ->
+  (b -> V.XRec V.Identity (a ': as)) ->
+  V.Rec f (a ': as) ->
+  f b
 gatheredN1MapRec f g = invmap f g . gatheredN1Rec
 
 -- | 'gatherN' but with at least one argument, so can be used with any
 -- 'Inply'.
 --
 -- @since 0.4.1.0
-gatherN1
-    :: forall f a as b. (Inply f, V.IsoXRec V.Identity as, V.RecordCurry as)
-    => V.Curried (a ': as) b
-    -> (b -> V.XRec V.Identity (a ': as))
-    -> V.CurriedF f (a ': as) (f b)
-gatherN1 f g = V.rcurry @(a ': as) @f $
+gatherN1 ::
+  forall f a as b.
+  (Inply f, V.IsoXRec V.Identity as, V.RecordCurry as) =>
+  V.Curried (a ': as) b ->
+  (b -> V.XRec V.Identity (a ': as)) ->
+  V.CurriedF f (a ': as) (f b)
+gatherN1 f g =
+  V.rcurry @(a ': as) @f $
     invmap (V.runcurry' f . V.fromXRec) g
-  . gatheredN1Rec
+      . gatheredN1Rec
 
 -- | Interpret out of a contravariant 'Day' into any instance of 'Apply' by
 -- providing two interpreting functions.
@@ -818,11 +976,12 @@ gatherN1 f g = V.rcurry @(a ': as) @f $
 -- instance of 'Inply'.  However, this can be handy if you are using an
 -- instance of 'Apply' that has no 'Inply' instance.  Consider also
 -- 'unsafeInplyCo' if you are using a specific, concrete type for @h@.
-runDayApply
-    :: forall f g h. Apply h
-    => f ~> h
-    -> g ~> h
-    -> Day f g ~> h
+runDayApply ::
+  forall f g h.
+  Apply h =>
+  f ~> h ->
+  g ~> h ->
+  Day f g ~> h
 runDayApply f g (Day x y j _) = liftF2 j (f x) (g y)
 
 -- | Interpret out of a contravariant 'Day' into any instance of 'Divise'
@@ -833,10 +992,10 @@ runDayApply f g (Day x y j _) = liftF2 j (f x) (g y)
 -- instance of 'Inply'.  However, this can be handy if you are using an
 -- instance of 'Divise' that has no 'Inply' instance.  Consider also
 -- 'unsafeInplyContra' if you are using a specific, concrete type for @h@.
-runDayDivise
-    :: forall f g h. Divise h
-    => f ~> h
-    -> g ~> h
-    -> Day f g ~> h
+runDayDivise ::
+  forall f g h.
+  Divise h =>
+  f ~> h ->
+  g ~> h ->
+  Day f g ~> h
 runDayDivise f g (Day x y _ h) = divise h (f x) (g y)
-
