@@ -1,41 +1,44 @@
 {-# OPTIONS_HADDOCK hide, not-home #-}
 
 module Data.HFunctor.Chain.Internal (
-    Chain1(..)
-  , foldChain1, unfoldChain1
-  , foldChain1A
-  , toChain1, injectChain1
-  , matchChain1
-  , Chain(..)
-  , foldChain, unfoldChain
-  , foldChainA
-  , splittingChain, unconsChain
-  , DivAp1(..)
-  , DivAp(..)
-  , DecAlt(..)
-  , DecAlt1(..)
-  ) where
+  Chain1 (..),
+  foldChain1,
+  unfoldChain1,
+  foldChain1A,
+  toChain1,
+  injectChain1,
+  matchChain1,
+  Chain (..),
+  foldChain,
+  unfoldChain,
+  foldChainA,
+  splittingChain,
+  unconsChain,
+  DivAp1 (..),
+  DivAp (..),
+  DecAlt (..),
+  DecAlt1 (..),
+) where
 
-import           Control.Monad.Freer.Church
-import           Control.Natural
-import           Control.Natural.IsoF
-import           Data.Functor.Apply
-import           Data.Functor.Classes
-import           Data.Functor.Contravariant
-import           Data.Functor.Identity
-import           Data.Functor.Invariant
-import           Data.Functor.Invariant.Internative
-import           Data.HBifunctor
-import           Data.HFunctor
-import           Data.HFunctor.Interpret
-import           Data.HFunctor.HTraversable
-import           Data.Kind
-import           Data.Typeable
-import           Data.Void
-import           GHC.Generics
-import qualified Data.Functor.Invariant.Day   as ID
+import Control.Monad.Freer.Church
+import Control.Natural
+import Control.Natural.IsoF
+import Data.Functor.Apply
+import Data.Functor.Classes
+import Data.Functor.Contravariant
+import Data.Functor.Identity
+import Data.Functor.Invariant
+import qualified Data.Functor.Invariant.Day as ID
+import Data.Functor.Invariant.Internative
 import qualified Data.Functor.Invariant.Night as IN
-
+import Data.HBifunctor
+import Data.HFunctor
+import Data.HFunctor.HTraversable
+import Data.HFunctor.Interpret
+import Data.Kind
+import Data.Typeable
+import Data.Void
+import GHC.Generics
 
 -- | A useful construction that works like a "non-empty linked list" of @t
 -- f@ applied to itself multiple times.  That is, it contains @t f f@, @t
@@ -92,8 +95,9 @@ import qualified Data.Functor.Invariant.Night as IN
 --
 --
 -- This construction is inspired by iteratees and machines.
-data Chain1 t f a = Done1 (f a)
-                  | More1 (t f (Chain1 t f) a)
+data Chain1 t f a
+  = Done1 (f a)
+  | More1 (t f (Chain1 t f) a)
   deriving (Typeable, Generic)
 
 deriving instance (Eq (f a), Eq (t f (Chain1 t f) a)) => Eq (Chain1 t f a)
@@ -105,50 +109,51 @@ deriving instance (Foldable f, Foldable (t f (Chain1 t f))) => Foldable (Chain1
 deriving instance (Traversable f, Traversable (t f (Chain1 t f))) => Traversable (Chain1 t f)
 
 instance (Eq1 f, Eq1 (t f (Chain1 t f))) => Eq1 (Chain1 t f) where
-    liftEq eq = \case
-      Done1 x -> \case
-        Done1 y -> liftEq eq x y
-        More1 _ -> False
-      More1 x -> \case
-        Done1 _ -> False
-        More1 y -> liftEq eq x y
+  liftEq eq = \case
+    Done1 x -> \case
+      Done1 y -> liftEq eq x y
+      More1 _ -> False
+    More1 x -> \case
+      Done1 _ -> False
+      More1 y -> liftEq eq x y
 
 instance (Ord1 f, Ord1 (t f (Chain1 t f))) => Ord1 (Chain1 t f) where
-    liftCompare c = \case
-      Done1 x -> \case
-        Done1 y -> liftCompare c x y
-        More1 _ -> LT
-      More1 x -> \case
-        Done1 _ -> GT
-        More1 y -> liftCompare c x y
+  liftCompare c = \case
+    Done1 x -> \case
+      Done1 y -> liftCompare c x y
+      More1 _ -> LT
+    More1 x -> \case
+      Done1 _ -> GT
+      More1 y -> liftCompare c x y
 
 instance (Show1 (t f (Chain1 t f)), Show1 f) => Show1 (Chain1 t f) where
-    liftShowsPrec sp sl d = \case
-        Done1 x  -> showsUnaryWith (liftShowsPrec sp sl) "Done1" d x
-        More1 xs -> showsUnaryWith (liftShowsPrec sp sl) "More1" d xs
+  liftShowsPrec sp sl d = \case
+    Done1 x -> showsUnaryWith (liftShowsPrec sp sl) "Done1" d x
+    More1 xs -> showsUnaryWith (liftShowsPrec sp sl) "More1" d xs
 
 instance (Functor f, Read1 (t f (Chain1 t f)), Read1 f) => Read1 (Chain1 t f) where
-    liftReadsPrec rp rl = readsData $
-            readsUnaryWith (liftReadsPrec rp rl) "Done1" Done1
-         <> readsUnaryWith (liftReadsPrec rp rl) "More1" More1
+  liftReadsPrec rp rl =
+    readsData $
+      readsUnaryWith (liftReadsPrec rp rl) "Done1" Done1
+        <> readsUnaryWith (liftReadsPrec rp rl) "More1" More1
 
 -- | @since 0.3.0.0
 instance (Contravariant f, Contravariant (t f (Chain1 t f))) => Contravariant (Chain1 t f) where
-    contramap f = \case
-      Done1 x  -> Done1 (contramap f x )
-      More1 xs -> More1 (contramap f xs)
+  contramap f = \case
+    Done1 x -> Done1 (contramap f x)
+    More1 xs -> More1 (contramap f xs)
 
 -- | @since 0.3.0.0
 instance (Invariant f, Invariant (t f (Chain1 t f))) => Invariant (Chain1 t f) where
-    invmap f g = \case
-      Done1 x  -> Done1 (invmap f g x )
-      More1 xs -> More1 (invmap f g xs)
+  invmap f g = \case
+    Done1 x -> Done1 (invmap f g x)
+    More1 xs -> More1 (invmap f g xs)
 
 instance HBifunctor t => HFunctor (Chain1 t) where
-    hmap f = foldChain1 (Done1 . f) (More1 . hleft f)
+  hmap f = foldChain1 (Done1 . f) (More1 . hleft f)
 
 instance HBifunctor t => Inject (Chain1 t) where
-    inject  = injectChain1
+  inject = injectChain1
 
 -- | Recursively fold down a 'Chain1'.  Provide a function on how to handle
 -- the "single @f@ case" ('inject'), and how to handle the "combined @t
@@ -156,27 +161,32 @@ instance HBifunctor t => Inject (Chain1 t) where
 -- @g@.
 --
 -- This is a catamorphism.
-foldChain1
-    :: forall t f g. HBifunctor t
-    => f ~> g                   -- ^ handle 'Done1'
-    -> t f g ~> g               -- ^ handle 'More1'
-    -> Chain1 t f ~> g
+foldChain1 ::
+  forall t f g.
+  HBifunctor t =>
+  -- | handle 'Done1'
+  f ~> g ->
+  -- | handle 'More1'
+  t f g ~> g ->
+  Chain1 t f ~> g
 foldChain1 f g = go
   where
     go :: Chain1 t f ~> g
     go = \case
-      Done1 x  -> f x
+      Done1 x -> f x
       More1 xs -> g (hright go xs)
 
 -- | An "effectful" version of 'foldChain1', weaving Applicative effects.
 --
 -- @since 0.3.6.0
-foldChain1A
-    :: (HBifunctor t, Functor h)
-    => (forall x. f x -> h (g x))                -- ^ handle 'Done1'
-    -> (forall x. t f (Comp h g) x -> h (g x))   -- ^ handle 'More1'
-    -> Chain1 t f a
-    -> h (g a)
+foldChain1A ::
+  (HBifunctor t, Functor h) =>
+  -- | handle 'Done1'
+  (forall x. f x -> h (g x)) ->
+  -- | handle 'More1'
+  (forall x. t f (Comp h g) x -> h (g x)) ->
+  Chain1 t f a ->
+  h (g a)
 foldChain1A f g = unComp . foldChain1 (Comp . f) (Comp . g)
 
 -- | Recursively build up a 'Chain1'.  Provide a function that takes some
@@ -184,10 +194,11 @@ foldChain1A f g = unComp . foldChain1 (Comp . f) (Comp . g)
 -- (@t f g@), and it will create a @'Chain1' t f@ from a @g@.
 --
 -- This is an anamorphism.
-unfoldChain1
-    :: forall t f (g :: Type -> Type). HBifunctor t
-    => (g ~> f :+: t f g)
-    -> g ~> Chain1 t f
+unfoldChain1 ::
+  forall t f (g :: Type -> Type).
+  HBifunctor t =>
+  (g ~> f :+: t f g) ->
+  g ~> Chain1 t f
 unfoldChain1 f = go
   where
     go :: g ~> Chain1 t f
@@ -212,8 +223,8 @@ injectChain1 = Done1
 -- @since 0.3.0.0
 matchChain1 :: Chain1 t f ~> (f :+: t f (Chain1 t f))
 matchChain1 = \case
-    Done1 x  -> L1 x
-    More1 xs -> R1 xs
+  Done1 x -> L1 x
+  More1 xs -> R1 xs
 
 -- | A useful construction that works like a "linked list" of @t f@ applied
 -- to itself multiple times.  That is, it contains @t f f@, @t f (t f f)@,
@@ -260,8 +271,9 @@ matchChain1 = \case
 --
 -- This construction is inspired by
 -- <http://oleg.fi/gists/posts/2018-02-21-single-free.html>
-data Chain t i f a = Done (i a)
-                   | More (t f (Chain t i f) a)
+data Chain t i f a
+  = Done (i a)
+  | More (t f (Chain t i f) a)
 
 deriving instance (Eq (i a), Eq (t f (Chain t i f) a)) => Eq (Chain t i f a)
 deriving instance (Ord (i a), Ord (t f (Chain t i f) a)) => Ord (Chain t i f a)
@@ -272,72 +284,78 @@ deriving instance (Foldable i, Foldable (t f (Chain t i f))) => Foldable (Chain
 deriving instance (Traversable i, Traversable (t f (Chain t i f))) => Traversable (Chain t i f)
 
 instance (Eq1 i, Eq1 (t f (Chain t i f))) => Eq1 (Chain t i f) where
-    liftEq eq = \case
-      Done x -> \case
-        Done y -> liftEq eq x y
-        More _ -> False
-      More x -> \case
-        Done _ -> False
-        More y -> liftEq eq x y
+  liftEq eq = \case
+    Done x -> \case
+      Done y -> liftEq eq x y
+      More _ -> False
+    More x -> \case
+      Done _ -> False
+      More y -> liftEq eq x y
 
 instance (Ord1 i, Ord1 (t f (Chain t i f))) => Ord1 (Chain t i f) where
-    liftCompare c = \case
-      Done x -> \case
-        Done y -> liftCompare c x y
-        More _ -> LT
-      More x -> \case
-        Done _ -> GT
-        More y -> liftCompare c x y
+  liftCompare c = \case
+    Done x -> \case
+      Done y -> liftCompare c x y
+      More _ -> LT
+    More x -> \case
+      Done _ -> GT
+      More y -> liftCompare c x y
 
 instance (Show1 (t f (Chain t i f)), Show1 i) => Show1 (Chain t i f) where
-    liftShowsPrec sp sl d = \case
-        Done x  -> showsUnaryWith (liftShowsPrec sp sl) "Done" d x
-        More xs -> showsUnaryWith (liftShowsPrec sp sl) "More" d xs
+  liftShowsPrec sp sl d = \case
+    Done x -> showsUnaryWith (liftShowsPrec sp sl) "Done" d x
+    More xs -> showsUnaryWith (liftShowsPrec sp sl) "More" d xs
 
 instance (Functor i, Read1 (t f (Chain t i f)), Read1 i) => Read1 (Chain t i f) where
-    liftReadsPrec rp rl = readsData $
-            readsUnaryWith (liftReadsPrec rp rl) "Done" Done
-         <> readsUnaryWith (liftReadsPrec rp rl) "More" More
+  liftReadsPrec rp rl =
+    readsData $
+      readsUnaryWith (liftReadsPrec rp rl) "Done" Done
+        <> readsUnaryWith (liftReadsPrec rp rl) "More" More
 
 instance (Contravariant i, Contravariant (t f (Chain t i f))) => Contravariant (Chain t i f) where
-    contramap f = \case
-      Done x  -> Done (contramap f x )
-      More xs -> More (contramap f xs)
+  contramap f = \case
+    Done x -> Done (contramap f x)
+    More xs -> More (contramap f xs)
 
 instance (Invariant i, Invariant (t f (Chain t i f))) => Invariant (Chain t i f) where
-    invmap f g = \case
-      Done x  -> Done (invmap f g x )
-      More xs -> More (invmap f g xs)
+  invmap f g = \case
+    Done x -> Done (invmap f g x)
+    More xs -> More (invmap f g xs)
 
 instance HBifunctor t => HFunctor (Chain t i) where
-    hmap f = foldChain Done (More . hleft f)
+  hmap f = foldChain Done (More . hleft f)
 
 -- | Recursively fold down a 'Chain'.  Provide a function on how to handle
 -- the "single @f@ case" ('nilLB'), and how to handle the "combined @t f g@
 -- case", and this will fold the entire @'Chain' t i) f@ into a single @g@.
 --
 -- This is a catamorphism.
-foldChain
-    :: forall t i f g. HBifunctor t
-    => (i ~> g)             -- ^ Handle 'Done'
-    -> (t f g ~> g)         -- ^ Handle 'More'
-    -> Chain t i f ~> g
+foldChain ::
+  forall t i f g.
+  HBifunctor t =>
+  -- | Handle 'Done'
+  (i ~> g) ->
+  -- | Handle 'More'
+  (t f g ~> g) ->
+  Chain t i f ~> g
 foldChain f g = go
   where
     go :: Chain t i f ~> g
     go = \case
-      Done x  -> f x
+      Done x -> f x
       More xs -> g (hright go xs)
 
 -- | An "effectful" version of 'foldChain', weaving Applicative effects.
 --
 -- @since 0.3.6.0
-foldChainA
-    :: (HBifunctor t, Functor h)
-    => (forall x. i x -> h (g x))         -- ^ Handle 'Done'
-    -> (forall x. t f (Comp h g) x -> h (g x))     -- ^ Handle 'More'
-    -> Chain t i f a
-    -> h (g a)
+foldChainA ::
+  (HBifunctor t, Functor h) =>
+  -- | Handle 'Done'
+  (forall x. i x -> h (g x)) ->
+  -- | Handle 'More'
+  (forall x. t f (Comp h g) x -> h (g x)) ->
+  Chain t i f a ->
+  h (g a)
 foldChainA f g = unComp . foldChain (Comp . f) (Comp . g)
 
 -- | Recursively build up a 'Chain'.  Provide a function that takes some
@@ -345,14 +363,15 @@ foldChainA f g = unComp . foldChain (Comp . f) (Comp . g)
 -- (@t f g@), and it will create a @'Chain' t i f@ from a @g@.
 --
 -- This is an anamorphism.
-unfoldChain
-    :: forall t f (g :: Type -> Type) i. HBifunctor t
-    => (g ~> i :+: t f g)
-    -> g ~> Chain t i f
+unfoldChain ::
+  forall t f (g :: Type -> Type) i.
+  HBifunctor t =>
+  (g ~> i :+: t f g) ->
+  g ~> Chain t i f
 unfoldChain f = go
   where
     go :: g a -> Chain t i f a
-    go = (\case L1 x -> Done x; R1 y ->  More (hright go y)) . f
+    go = (\case L1 x -> Done x; R1 y -> More (hright go y)) . f
 
 -- | For completeness, an isomorphism between 'Chain' and its two
 -- constructors, to match 'splittingLB'.
@@ -360,8 +379,8 @@ unfoldChain f = go
 -- @since 0.3.0.0
 splittingChain :: Chain t i f <~> (i :+: t f (Chain t i f))
 splittingChain = isoF unconsChain $ \case
-      L1 x  -> Done x
-      R1 xs -> More xs
+  L1 x -> Done x
+  R1 xs -> More xs
 
 -- | An analogue of 'unconsLB': match one of the two constructors of
 -- a 'Chain'.
@@ -369,8 +388,8 @@ splittingChain = isoF unconsChain $ \case
 -- @since 0.3.0.0
 unconsChain :: Chain t i f ~> i :+: t f (Chain t i f)
 unconsChain = \case
-    Done x  -> L1 x
-    More xs -> R1 xs
+  Done x -> L1 x
+  More xs -> R1 xs
 
 -- | The invariant version of 'Ap1' and 'Div1': combines the capabilities
 -- of both 'Ap1' and 'Div1' together.
@@ -401,27 +420,31 @@ unconsChain = \case
 -- it.
 --
 -- @since 0.3.5.0
-newtype DivAp1 f a = DivAp1_ { unDivAp1 :: Chain1 ID.Day f a }
+newtype DivAp1 f a = DivAp1_ {unDivAp1 :: Chain1 ID.Day f a}
   deriving (Invariant, HFunctor, Inject)
 
 instance HTraversable DivAp1 where
-    htraverse f =
-        foldChain1A
-          (fmap (DivAp1_ . Done1) . f)
-          (\case ID.Day x (Comp y) g h ->
-                     (\x' y' -> DivAp1_ (More1 (ID.Day x' y' g h)))
-                   <$> f x <*> (unDivAp1 <$> y)
-          )
+  htraverse f =
+    foldChain1A
+      (fmap (DivAp1_ . Done1) . f)
+      ( \case
+          ID.Day x (Comp y) g h ->
+            (\x' y' -> DivAp1_ (More1 (ID.Day x' y' g h)))
+              <$> f x
+              <*> (unDivAp1 <$> y)
+      )
       . unDivAp1
 
 instance HTraversable1 DivAp1 where
-    htraverse1 f =
-        foldChain1A
-          (fmap (DivAp1_ . Done1) . f)
-          (\case ID.Day x (Comp y) g h ->
-                     (\x' y' -> DivAp1_ (More1 (ID.Day x' y' g h)))
-                   <$> f x <.> (unDivAp1 <$> y)
-          )
+  htraverse1 f =
+    foldChain1A
+      (fmap (DivAp1_ . Done1) . f)
+      ( \case
+          ID.Day x (Comp y) g h ->
+            (\x' y' -> DivAp1_ (More1 (ID.Day x' y' g h)))
+              <$> f x
+              <.> (unDivAp1 <$> y)
+      )
       . unDivAp1
 
 -- | The invariant version of 'Ap' and 'Div': combines the capabilities of
@@ -454,23 +477,24 @@ instance HTraversable1 DivAp1 where
 -- assemble it.
 --
 -- @since 0.3.5.0
-newtype DivAp f a = DivAp { unDivAp :: Chain ID.Day Identity f a }
+newtype DivAp f a = DivAp {unDivAp :: Chain ID.Day Identity f a}
   deriving (Invariant, HFunctor)
 
 instance Inject DivAp where
-    inject x = DivAp $ More (ID.Day x (Done (Identity ())) const (,()))
+  inject x = DivAp $ More (ID.Day x (Done (Identity ())) const (,()))
 
 instance HTraversable DivAp where
-    htraverse f =
-        foldChainA
-          (pure . DivAp . Done)
-          (\case ID.Day x (Comp y) g h ->
-                      (\x' y' -> DivAp (More (ID.Day x'  y' g h)))
-                  <$> f x <*> (unDivAp <$> y)
-          )
+  htraverse f =
+    foldChainA
+      (pure . DivAp . Done)
+      ( \case
+          ID.Day x (Comp y) g h ->
+            (\x' y' -> DivAp (More (ID.Day x' y' g h)))
+              <$> f x
+              <*> (unDivAp <$> y)
+      )
       . unDivAp
 
-
 -- | The invariant version of 'NonEmptyF' and 'Dec1': combines the
 -- capabilities of both 'NonEmptyF' and 'Dec1' together.
 --
@@ -499,32 +523,36 @@ instance HTraversable DivAp where
 -- assemble it.
 --
 -- @since 0.3.5.0
-newtype DecAlt1 f a = DecAlt1_ { unDecAlt1 :: Chain1 IN.Night f a }
+newtype DecAlt1 f a = DecAlt1_ {unDecAlt1 :: Chain1 IN.Night f a}
   deriving (Invariant, HFunctor, Inject)
 
 instance HTraversable DecAlt1 where
-    htraverse f =
-        foldChain1A
-          (fmap (DecAlt1_ . Done1) . f)
-          (\case IN.Night x (Comp y) g h k ->
-                     (\x' y' -> DecAlt1_ (More1 (IN.Night x' y' g h k)))
-                   <$> f x <*> (unDecAlt1 <$> y)
-          )
+  htraverse f =
+    foldChain1A
+      (fmap (DecAlt1_ . Done1) . f)
+      ( \case
+          IN.Night x (Comp y) g h k ->
+            (\x' y' -> DecAlt1_ (More1 (IN.Night x' y' g h k)))
+              <$> f x
+              <*> (unDecAlt1 <$> y)
+      )
       . unDecAlt1
 
 instance HTraversable1 DecAlt1 where
-    htraverse1 f =
-        foldChain1A
-          (fmap (DecAlt1_ . Done1) . f)
-          (\case IN.Night x (Comp y) g h k ->
-                     (\x' y' -> DecAlt1_ (More1 (IN.Night x' y' g h k)))
-                   <$> f x <.> (unDecAlt1 <$> y)
-          )
+  htraverse1 f =
+    foldChain1A
+      (fmap (DecAlt1_ . Done1) . f)
+      ( \case
+          IN.Night x (Comp y) g h k ->
+            (\x' y' -> DecAlt1_ (More1 (IN.Night x' y' g h k)))
+              <$> f x
+              <.> (unDecAlt1 <$> y)
+      )
       . unDecAlt1
 
 -- | A free 'Inalt'
 instance Inalt f => Interpret DecAlt1 f where
-    interpret f (DecAlt1_ x) = foldChain1 f (IN.runNight f id) x
+  interpret f (DecAlt1_ x) = foldChain1 f (IN.runNight f id) x
 
 -- | The invariant version of 'ListF' and 'Dec': combines the capabilities of
 -- both 'ListF' and 'Dec' together.
@@ -556,21 +584,24 @@ instance Inalt f => Interpret DecAlt1 f where
 -- assemble it.
 --
 -- @since 0.3.5.0
-newtype DecAlt f a = DecAlt { unDecAlt :: Chain IN.Night IN.Not f a }
+newtype DecAlt f a = DecAlt {unDecAlt :: Chain IN.Night IN.Not f a}
   deriving (Invariant, HFunctor)
 
 instance Inject DecAlt where
-    inject x = DecAlt $ More (IN.Night x (Done IN.refuted) id absurd Left)
+  inject x = DecAlt $ More (IN.Night x (Done IN.refuted) id absurd Left)
 
 instance HTraversable DecAlt where
-    htraverse f =
-        foldChainA (pure . DecAlt . Done)
-          (\case IN.Night x (Comp y) g h k ->
-                     (\x' y' -> DecAlt (More (IN.Night x' y' g h k)))
-                  <$> f x <*> (unDecAlt <$> y)
-          )
+  htraverse f =
+    foldChainA
+      (pure . DecAlt . Done)
+      ( \case
+          IN.Night x (Comp y) g h k ->
+            (\x' y' -> DecAlt (More (IN.Night x' y' g h k)))
+              <$> f x
+              <*> (unDecAlt <$> y)
+      )
       . unDecAlt
 
 -- | A free 'Inplus'
 instance Inplus f => Interpret DecAlt f where
-    interpret f (DecAlt x) = foldChain (reject . IN.refute) (IN.runNight f id) x
+  interpret f (DecAlt x) = foldChain (reject . IN.refute) (IN.runNight f id) x
