@@ -1,6 +1,6 @@
 -- |
 -- Module      : Data.HFunctor.Interpret
--- Copyright   : (c) Justin Le 2019
+-- Copyright   : (c) Justin Le 2025
 -- License     : BSD3
 --
 -- Maintainer  : justin@jle.im
@@ -41,62 +41,65 @@
 -- See "Data.Functor.Tensor" for binary functor combinators that mix
 -- together two or more different functors.
 module Data.HFunctor.Interpret (
-    Interpret(..), forI
-  -- * Utilities
-  , iget
-  , icollect
-  , icollect1
-  , itraverse
-  , iapply
-  , ifanout
-  , ifanout1
-  , getI, collectI
-  , AltConst(..)
-  , AndC
-  , WrapHF(..)
-  ) where
+  Interpret (..),
+  forI,
 
-import           Control.Applicative
-import           Control.Applicative.Backwards
-import           Control.Applicative.Lift
-import           Control.Applicative.ListF
-import           Control.Applicative.Step
-import           Control.Comonad.Trans.Env            (EnvT(..))
-import           Control.Monad.Freer.Church
-import           Control.Monad.Reader
-import           Control.Monad.Trans.Compose
-import           Control.Monad.Trans.Identity
-import           Control.Natural
-import           Data.Coerce
-import           Data.Data
-import           Data.Functor.Bind
-import           Data.Functor.Classes
-import           Data.Functor.Contravariant
-import           Data.Functor.Contravariant.Conclude
-import           Data.Functor.Contravariant.Decide
-import           Data.Functor.Contravariant.Divise
-import           Data.Functor.Contravariant.Divisible
-import           Data.Functor.Coyoneda
-import           Data.Functor.Invariant
-import           Data.Functor.Plus
-import           Data.Functor.Product
-import           Data.Functor.Reverse
-import           Data.Functor.Sum
-import           Data.Functor.These
-import           Data.HFunctor
-import           Data.HFunctor.Internal
-import           Data.List.NonEmpty                   (NonEmpty(..))
-import           Data.Maybe
-import           Data.Pointed
-import           Data.Semigroup                       (Endo(..))
-import           Data.Semigroup.Foldable
-import           GHC.Generics
-import qualified Control.Alternative.Free             as Alt
-import qualified Control.Applicative.Free             as Ap
-import qualified Control.Applicative.Free.Fast        as FAF
-import qualified Control.Applicative.Free.Final       as FA
-import qualified Data.Functor.Contravariant.Coyoneda  as CCY
-import qualified Data.Map.NonEmpty                    as NEM
+  -- * Utilities
+  iget,
+  icollect,
+  icollect1,
+  itraverse,
+  iapply,
+  ifanout,
+  ifanout1,
+  getI,
+  collectI,
+  AltConst (..),
+  AndC,
+  WrapHF (..),
+) where
+
+import qualified Control.Alternative.Free as Alt
+import Control.Applicative
+import Control.Applicative.Backwards
+import qualified Control.Applicative.Free as Ap
+import qualified Control.Applicative.Free.Fast as FAF
+import qualified Control.Applicative.Free.Final as FA
+import Control.Applicative.Lift
+import Control.Applicative.ListF
+import Control.Applicative.Step
+import Control.Comonad.Trans.Env (EnvT (..))
+import Control.Monad.Freer.Church
+import Control.Monad.Reader
+import Control.Monad.Trans.Compose
+import Control.Monad.Trans.Identity
+import Control.Natural
+import Data.Coerce
+import Data.Data
+import Data.Functor.Bind
+import Data.Functor.Classes
+import Data.Functor.Contravariant
+import Data.Functor.Contravariant.Conclude
+import qualified Data.Functor.Contravariant.Coyoneda as CCY
+import Data.Functor.Contravariant.Decide
+import Data.Functor.Contravariant.Divise
+import Data.Functor.Contravariant.Divisible
+import Data.Functor.Coyoneda
+import Data.Functor.Invariant
+import Data.Functor.Plus
+import Data.Functor.Product
+import Data.Functor.Reverse
+import Data.Functor.Sum
+import Data.Functor.These
+import Data.HFunctor
+import Data.HFunctor.Internal
+import Data.List.NonEmpty (NonEmpty (..))
+import qualified Data.Map.NonEmpty as NEM
+import Data.Maybe
+import Data.Pointed
+import Data.Semigroup (Endo (..))
+import Data.Semigroup.Foldable
+import GHC.Generics
 
 -- | An 'Interpret' lets us move in and out of the "enhanced" 'Functor' (@t
 -- f@) and the functor it enhances (@f@).  An instance @'Interpret' t f@
@@ -143,26 +146,25 @@ import qualified Data.Map.NonEmpty                    as NEM
 --
 -- This will prevent problems with overloaded instances.
 class Inject t => Interpret t f where
+  -- | Remove the @f@ out of the enhanced @t f@ structure, provided that
+  -- @f@ satisfies the necessary constraints.  If it doesn't, it needs to
+  -- be properly 'interpret'ed out.
+  retract :: t f ~> f
+  retract = interpret id
 
-    -- | Remove the @f@ out of the enhanced @t f@ structure, provided that
-    -- @f@ satisfies the necessary constraints.  If it doesn't, it needs to
-    -- be properly 'interpret'ed out.
-    retract :: t f ~> f
-    retract = interpret id
+  -- | Given an "interpeting function" from @f@ to @g@, interpret the @f@
+  -- out of the @t f@ into a final context @g@.
+  interpret :: (g ~> f) -> t g ~> f
+  interpret f = retract . hmap f
 
-    -- | Given an "interpeting function" from @f@ to @g@, interpret the @f@
-    -- out of the @t f@ into a final context @g@.
-    interpret :: (g ~> f) -> t g ~> f
-    interpret f = retract . hmap f
-
-    {-# MINIMAL retract | interpret #-}
+  {-# MINIMAL retract | interpret #-}
 
 -- | A convenient flipped version of 'interpret'.
-forI
-    :: Interpret t f
-    => t g a
-    -> (g ~> f)
-    -> f a
+forI ::
+  Interpret t f =>
+  t g a ->
+  (g ~> f) ->
+  f a
 forI x f = interpret f x
 
 -- | Useful wrapper over 'interpret' to allow you to directly extract
@@ -189,11 +191,11 @@ forI x f = interpret f x
 -- 'Data.HFunctor.HTraversable.hfoldMap1'.
 --
 -- @since 0.3.1.0
-iget
-    :: Interpret t (AltConst b)
-    => (forall x. f x -> b)
-    -> t f a
-    -> b
+iget ::
+  Interpret t (AltConst b) =>
+  (forall x. f x -> b) ->
+  t f a ->
+  b
 iget f = getAltConst . interpret (AltConst . f)
 
 -- | (Deprecated) Old name for 'getI'; will be removed in a future
@@ -222,11 +224,11 @@ getI = iget
 -- 'Data.HFunctor.HTraversable.htoList'.
 --
 -- @since 0.3.1.0
-icollect
-    :: (forall m. Monoid m => Interpret t (AltConst m))
-    => (forall x. f x -> b)
-    -> t f a
-    -> [b]
+icollect ::
+  (forall m. Monoid m => Interpret t (AltConst m)) =>
+  (forall x. f x -> b) ->
+  t f a ->
+  [b]
 icollect f = flip appEndo [] . iget (Endo . (:) . f)
 
 -- | (Deprecated) Old name for 'icollect'; will be removed in a future
@@ -254,11 +256,11 @@ collectI = icollect
 -- 'Data.HFunctor.HTraversable.htoNonEmpty'.
 --
 -- @since 0.3.1.0
-icollect1
-    :: (forall m. Semigroup m => Interpret t (AltConst m))
-    => (forall x. f x -> b)
-    -> t f a
-    -> NonEmpty b
+icollect1 ::
+  (forall m. Semigroup m => Interpret t (AltConst m)) =>
+  (forall x. f x -> b) ->
+  t f a ->
+  NonEmpty b
 icollect1 f = fromNDL . iget (ndlSingleton . f)
 
 -- | Useful wrapper over 'interpret' to allow you to do an "effectful"
@@ -269,11 +271,11 @@ icollect1 f = fromNDL . iget (ndlSingleton . f)
 -- which is a more principled system for effectful hmapping.
 --
 -- @since 0.3.6.0
-itraverse
-    :: (Functor h, Interpret t (Comp h (t g)))
-    => (forall x. f x -> h (g x))
-    -> t f a
-    -> h (t g a)
+itraverse ::
+  (Functor h, Interpret t (Comp h (t g))) =>
+  (forall x. f x -> h (g x)) ->
+  t f a ->
+  h (t g a)
 itraverse f = unComp . interpret (\x -> f x :>>= inject)
 
 -- | Useful wrapper over 'interpret' to allow you to directly consume
@@ -296,12 +298,12 @@ itraverse f = unComp . interpret (\x -> f x :>>= inject)
 -- For any 'Functor' or 'Invariant' constraint, this is not usable.
 --
 -- @since 0.3.2.0
-iapply
-    :: Interpret t (Op b)
-    => (forall x. f x -> x -> b)
-    -> t f a
-    -> a
-    -> b
+iapply ::
+  Interpret t (Op b) =>
+  (forall x. f x -> x -> b) ->
+  t f a ->
+  a ->
+  b
 iapply f = getOp . interpret (Op . f)
 
 -- | Useful wrapper over 'interpret' to allow you to directly consume
@@ -323,12 +325,12 @@ iapply f = getOp . interpret (Op . f)
 -- always just give you a singleton list, so you might as well use
 -- 'iapply'.  This is really only here for completion alongside 'icollect',
 -- or if you define your own custom functor combinators.
-ifanout
-    :: (forall m. Monoid m => Interpret t (Op m))
-    => (forall x. f x -> x -> b)
-    -> t f a
-    -> a
-    -> [b]
+ifanout ::
+  (forall m. Monoid m => Interpret t (Op m)) =>
+  (forall x. f x -> x -> b) ->
+  t f a ->
+  a ->
+  [b]
 ifanout f t = flip appEndo [] . iapply (\x y -> Endo (f x y :)) t
 
 -- | Useful wrapper over 'interpret' to allow you to directly consume
@@ -349,16 +351,14 @@ ifanout f t = flip appEndo [] . iapply (\x y -> Endo (f x y :)) t
 -- always just give you a singleton list, so you might as well use
 -- 'iapply'.  This is really only here for completion alongside
 -- 'icollect1', or if you define your own custom functor combinators.
-ifanout1
-    :: (forall m. Semigroup m => Interpret t (Op m))
-    => (forall x. f x -> x -> b)
-    -> t f a
-    -> a
-    -> NonEmpty b
+ifanout1 ::
+  (forall m. Semigroup m => Interpret t (Op m)) =>
+  (forall x. f x -> x -> b) ->
+  t f a ->
+  a ->
+  NonEmpty b
 ifanout1 f t = fromNDL . iapply (\x -> ndlSingleton . f x) t
 
-
-
 -- | A version of 'Const' that supports 'Alt', 'Plus', 'Decide', and
 -- 'Conclude' instances.  It does this
 -- by avoiding having an 'Alternative' or 'Decidable' instance, which
@@ -367,77 +367,81 @@ ifanout1 f t = fromNDL . iapply (\x -> ndlSingleton . f x) t
 -- 'Decidable'/'Data.Functor.Contravariant.Divisible.Divisible'.
 --
 -- @since 0.3.1.0
-newtype AltConst w a = AltConst { getAltConst :: w }
+newtype AltConst w a = AltConst {getAltConst :: w}
   deriving (Show, Eq, Ord, Generic, Functor, Foldable, Traversable, Data)
 
 instance Show w => Show1 (AltConst w) where
-    liftShowsPrec _ _ d (AltConst x) = showsUnaryWith showsPrec "AltConst" d x
+  liftShowsPrec _ _ d (AltConst x) = showsUnaryWith showsPrec "AltConst" d x
 instance Eq w => Eq1 (AltConst w) where
-    liftEq _ (AltConst x) (AltConst y) = x == y
+  liftEq _ (AltConst x) (AltConst y) = x == y
 instance Ord w => Ord1 (AltConst w) where
-    liftCompare _ (AltConst x) (AltConst y) = compare x y
+  liftCompare _ (AltConst x) (AltConst y) = compare x y
 
 instance Contravariant (AltConst w) where
-    contramap _ = coerce
+  contramap _ = coerce
 instance Invariant (AltConst w) where
-    invmap _ _ = coerce
+  invmap _ _ = coerce
 
 instance Semigroup w => Apply (AltConst w) where
-    AltConst x <.> AltConst y = AltConst (x <> y)
+  AltConst x <.> AltConst y = AltConst (x <> y)
 instance Monoid w => Applicative (AltConst w) where
-    (<*>) = (<.>)
-    pure _ = AltConst mempty
+  (<*>) = (<.>)
+  pure _ = AltConst mempty
+
 -- | Unlike for 'Const', this is possible because there is no 'Alternative'
 -- instance to complicate things.
 instance Semigroup w => Alt (AltConst w) where
-    AltConst x <!> AltConst y = AltConst (x <> y)
+  AltConst x <!> AltConst y = AltConst (x <> y)
+
 -- | Unlike for 'Const', this is possible because there is no 'Alternative'
 -- instance to complicate things.
 instance Monoid w => Plus (AltConst w) where
-    zero = AltConst mempty
+  zero = AltConst mempty
 
 instance Semigroup w => Divise (AltConst w) where
-    divise _ (AltConst x) (AltConst y) = AltConst (x <> y)
+  divise _ (AltConst x) (AltConst y) = AltConst (x <> y)
 instance Monoid w => Divisible (AltConst w) where
-    divide  = divise
-    conquer = AltConst mempty
+  divide = divise
+  conquer = AltConst mempty
+
 -- | Unlike for 'Const', this is possible because there is no 'Decidable'
 -- instance to complicate things.
 instance Semigroup w => Decide (AltConst w) where
-    decide _ (AltConst x) (AltConst y) = AltConst (x <> y)
+  decide _ (AltConst x) (AltConst y) = AltConst (x <> y)
+
 -- | Unlike for 'Const', this is possible because there is no 'Decidable'
 -- instance to complicate things.
 instance Monoid w => Conclude (AltConst w) where
-    conclude _ = AltConst mempty
+  conclude _ = AltConst mempty
 
 -- | A free 'Functor'
 instance Functor f => Interpret Coyoneda f where
-    retract                    = lowerCoyoneda
-    interpret f (Coyoneda g x) = g <$> f x
+  retract = lowerCoyoneda
+  interpret f (Coyoneda g x) = g <$> f x
 
 -- | A free 'Contravariant'
 --
 -- @since 0.3.0.0
 instance Contravariant f => Interpret CCY.Coyoneda f where
-    retract                        = CCY.lowerCoyoneda
-    interpret f (CCY.Coyoneda g x) = contramap g (f x)
+  retract = CCY.lowerCoyoneda
+  interpret f (CCY.Coyoneda g x) = contramap g (f x)
 
 -- | A free 'Applicative'
 instance Applicative f => Interpret Ap.Ap f where
-    retract   = \case
-      Ap.Pure x  -> pure x
-      Ap.Ap x xs -> x <**> retract xs
-    interpret f x = Ap.runAp f x
+  retract = \case
+    Ap.Pure x -> pure x
+    Ap.Ap x xs -> x <**> retract xs
+  interpret f x = Ap.runAp f x
 
 -- | A free 'Plus'
 instance Plus f => Interpret ListF f where
-    retract     = foldr (<!>) zero . runListF
-    interpret f = foldr ((<!>) . f) zero . runListF
+  retract = foldr (<!>) zero . runListF
+  interpret f = foldr ((<!>) . f) zero . runListF
 
 -- | A free 'Alt'
 instance Alt f => Interpret NonEmptyF f where
-    retract     = asum1 . runNonEmptyF
-    interpret f = asum1 . fmap f . runNonEmptyF
+  retract = asum1 . runNonEmptyF
+  interpret f = asum1 . fmap f . runNonEmptyF
 
 -- | Technically, @f@ is over-constrained: we only need @'zero' :: f a@,
 -- but we don't really have that typeclass in any standard hierarchies.  We
@@ -446,32 +450,32 @@ instance Alt f => Interpret NonEmptyF f where
 -- instances of 'Control.Monad.Fail.MonadFail' without
 -- 'Control.Monad.MonadPlus'.
 instance Plus f => Interpret MaybeF f where
-    retract     = fromMaybe zero . runMaybeF
-    interpret f = maybe zero f . runMaybeF
+  retract = fromMaybe zero . runMaybeF
+  interpret f = maybe zero f . runMaybeF
 
 instance (Monoid k, Plus f) => Interpret (MapF k) f where
-    retract = foldr (<!>) zero . runMapF
-    interpret f = foldr ((<!>) . f) zero . runMapF
+  retract = foldr (<!>) zero . runMapF
+  interpret f = foldr ((<!>) . f) zero . runMapF
 
 instance (Monoid k, Alt f) => Interpret (NEMapF k) f where
-    retract = asum1 . runNEMapF
-    interpret f = asum1 . fmap f . runNEMapF
+  retract = asum1 . runNEMapF
+  interpret f = asum1 . fmap f . runNEMapF
 
 -- | Equivalent to instance for @'EnvT' ('Data.Semigroup.Sum'
 -- 'Numeric.Natural.Natural')@.
 instance Interpret Step f where
-    retract = stepVal
-    interpret f = f . stepVal
+  retract = stepVal
+  interpret f = f . stepVal
 
 instance Alt f => Interpret Steps f where
-    retract     = asum1 . getSteps
-    interpret f = asum1 . NEM.map f . getSteps
+  retract = asum1 . getSteps
+  interpret f = asum1 . NEM.map f . getSteps
 
 -- | Equivalent to instance for @'EnvT' 'Data.Semigroup.Any'@ and @'HLift'
 -- 'IdentityT'@.
 instance Interpret Flagged f where
-    retract = flaggedVal
-    interpret f = f . flaggedVal
+  retract = flaggedVal
+  interpret f = f . flaggedVal
 
 -- | Technically, @f@ is over-constrained: we only need @'zero' :: f a@,
 -- but we don't really have that typeclass in any standard hierarchies.  We
@@ -480,24 +484,24 @@ instance Interpret Flagged f where
 -- instances of 'Control.Monad.Fail.MonadFail' without
 -- 'Control.Monad.MonadPlus'.
 instance Plus f => Interpret (These1 g) f where
-    retract = \case
-      This1  _   -> zero
-      That1    y -> y
-      These1 _ y -> y
-    interpret f = \case
-      This1  _   -> zero
-      That1    y -> f y
-      These1 _ y -> f y
+  retract = \case
+    This1 _ -> zero
+    That1 y -> y
+    These1 _ y -> y
+  interpret f = \case
+    This1 _ -> zero
+    That1 y -> f y
+    These1 _ y -> f y
 
 -- | A free 'Alternative'
 instance Alternative f => Interpret Alt.Alt f where
-    interpret f x = Alt.runAlt f x
+  interpret f x = Alt.runAlt f x
 
 instance Plus g => Interpret ((:*:) g) f where
-    retract (_ :*: y) = y
+  retract (_ :*: y) = y
 
 instance Plus g => Interpret (Product g) f where
-    retract (Pair _ y) = y
+  retract (Pair _ y) = y
 
 -- | Technically, @f@ is over-constrained: we only need @'zero' :: f a@,
 -- but we don't really have that typeclass in any standard hierarchies.  We
@@ -506,9 +510,9 @@ instance Plus g => Interpret (Product g) f where
 -- instances of 'Control.Monad.Fail.MonadFail' without
 -- 'Control.Monad.MonadPlus'.
 instance Plus f => Interpret ((:+:) g) f where
-    retract = \case
-      L1 _ -> zero
-      R1 y -> y
+  retract = \case
+    L1 _ -> zero
+    R1 y -> y
 
 -- | Technically, @f@ is over-constrained: we only need @'zero' :: f a@,
 -- but we don't really have that typeclass in any standard hierarchies.  We
@@ -517,69 +521,69 @@ instance Plus f => Interpret ((:+:) g) f where
 -- instances of 'Control.Monad.Fail.MonadFail' without
 -- 'Control.Monad.MonadPlus'.
 instance Plus f => Interpret (Sum g) f where
-    retract = \case
-      InL _ -> zero
-      InR y -> y
+  retract = \case
+    InL _ -> zero
+    InR y -> y
 
 instance Interpret (M1 i c) f where
-    retract (M1 x) = x
-    interpret f (M1 x) = f x
+  retract (M1 x) = x
+  interpret f (M1 x) = f x
 
 -- | A free 'Monad'
 instance Monad f => Interpret Free f where
-    retract   = retractFree
-    interpret f x = interpretFree f x
+  retract = retractFree
+  interpret f x = interpretFree f x
 
 -- | A free 'Bind'
 instance Bind f => Interpret Free1 f where
-    retract   = retractFree1
-    interpret f x = interpretFree1 f x
+  retract = retractFree1
+  interpret f x = interpretFree1 f x
 
 -- | A free 'Applicative'
 instance Applicative f => Interpret FA.Ap f where
-    retract   = FA.retractAp
-    interpret f x = FA.runAp f x
+  retract = FA.retractAp
+  interpret f x = FA.runAp f x
 
 -- | A free 'Applicative'
 instance Applicative f => Interpret FAF.Ap f where
-    retract   = FAF.retractAp
-    interpret f x = FAF.runAp f x
+  retract = FAF.retractAp
+  interpret f x = FAF.runAp f x
 
 instance Interpret IdentityT f where
-    retract = coerce
-    interpret f = f . runIdentityT
+  retract = coerce
+  interpret f = f . runIdentityT
 
 -- | A free 'Pointed'
 instance Pointed f => Interpret Lift f where
-    retract   = elimLift point id
-    interpret f x = elimLift point f x
+  retract = elimLift point id
+  interpret f x = elimLift point f x
 
 -- | A free 'Pointed'
 instance Pointed f => Interpret MaybeApply f where
-    retract     = either id point . runMaybeApply
-    interpret f = either f point . runMaybeApply
+  retract = either id point . runMaybeApply
+  interpret f = either f point . runMaybeApply
 
 instance Interpret Backwards f where
-    retract     = forwards
-    interpret f = f . forwards
+  retract = forwards
+  interpret f = f . forwards
 
 instance Interpret WrappedApplicative f where
-    retract     = unwrapApplicative
-    interpret f = f . unwrapApplicative
+  retract = unwrapApplicative
+  interpret f = f . unwrapApplicative
 
 -- | A free 'MonadReader', but only when applied to a 'Monad'.
 instance MonadReader r f => Interpret (ReaderT r) f where
-    retract     x = runReaderT x =<< ask
-    interpret f x = f . runReaderT x =<< ask
+  retract x = runReaderT x =<< ask
+  interpret f x = f . runReaderT x =<< ask
 
 -- | This ignores the environment, so @'interpret' /= 'hbind'@
 instance Monoid e => Interpret (EnvT e) f where
-    retract     (EnvT _ x) = x
-    interpret f (EnvT _ x) = f x
+  retract (EnvT _ x) = x
+  interpret f (EnvT _ x) = f x
 
 instance Interpret Reverse f where
-    retract     = getReverse
-    interpret f = f . getReverse
+  retract = getReverse
+  interpret f = f . getReverse
 
 -- -- | The only way for this to obey @'retract' . 'inject' == 'id'@ is to
 -- -- have it impossible to retract out of.
@@ -597,26 +601,27 @@ instance Interpret Reverse f where
 -- | A constraint on @a@ for both @c a@ and @d a@.  Requiring @'AndC'
 -- 'Show' 'Eq' a@ is the same as requiring @('Show' a, 'Eq' a)@.
 class (c a, d a) => AndC c d a
+
 instance (c a, d a) => AndC c d a
 
 instance (Interpret s f, Interpret t f) => Interpret (ComposeT s t) f where
-    retract     = interpret retract . getComposeT
-    interpret f = interpret (interpret f) . getComposeT
+  retract = interpret retract . getComposeT
+  interpret f = interpret (interpret f) . getComposeT
 
 -- | Never uses 'inject'
 instance Interpret t f => Interpret (HLift t) f where
-    retract = \case
-      HPure  x -> x
-      HOther x -> retract x
-    interpret f = \case
-      HPure  x -> f x
-      HOther x -> interpret f x
+  retract = \case
+    HPure x -> x
+    HOther x -> retract x
+  interpret f = \case
+    HPure x -> f x
+    HOther x -> interpret f x
 
 -- | Never uses 'inject'
 instance Interpret t f => Interpret (HFree t) f where
-    retract = \case
-      HReturn x -> x
-      HJoin   x -> interpret retract x
+  retract = \case
+    HReturn x -> x
+    HJoin x -> interpret retract x
 
 -- | A newtype wrapper meant to be used to define polymorphic 'Interpret'
 -- instances.  See documentation for 'Interpret' for more information.
@@ -629,25 +634,24 @@ instance Interpret t f => Interpret (HFree t) f where
 -- @
 --
 -- As that would globally ruin everything using 'WrapHF'.
-newtype WrapHF t f a = WrapHF { unwrapHF :: t f a }
+newtype WrapHF t f a = WrapHF {unwrapHF :: t f a}
   deriving (Show, Read, Eq, Ord, Functor, Foldable, Traversable, Typeable, Generic, Data)
 
 instance Show1 (t f) => Show1 (WrapHF t f) where
-    liftShowsPrec sp sl d (WrapHF x) = showsUnaryWith (liftShowsPrec sp sl) "WrapHF" d x
+  liftShowsPrec sp sl d (WrapHF x) = showsUnaryWith (liftShowsPrec sp sl) "WrapHF" d x
 
 instance Eq1 (t f) => Eq1 (WrapHF t f) where
-    liftEq eq (WrapHF x) (WrapHF y) = liftEq eq x y
+  liftEq eq (WrapHF x) (WrapHF y) = liftEq eq x y
 
 instance Ord1 (t f) => Ord1 (WrapHF t f) where
-    liftCompare c (WrapHF x) (WrapHF y) = liftCompare c x y
+  liftCompare c (WrapHF x) (WrapHF y) = liftCompare c x y
 
 instance HFunctor t => HFunctor (WrapHF t) where
-    hmap f (WrapHF x) = WrapHF (hmap f x)
+  hmap f (WrapHF x) = WrapHF (hmap f x)
 
 instance Inject t => Inject (WrapHF t) where
-    inject = WrapHF . inject
+  inject = WrapHF . inject
 
 instance HBind t => HBind (WrapHF t) where
-    hbind f (WrapHF x) = WrapHF (hbind (unwrapHF . f) x)
-    hjoin (WrapHF x) = WrapHF (hbind unwrapHF x)
-
+  hbind f (WrapHF x) = WrapHF (hbind (unwrapHF . f) x)
+  hjoin (WrapHF x) = WrapHF (hbind unwrapHF x)
